@@ -3,7 +3,7 @@ from sanic.response import json
 from ..handler import FileHandlerProcess
 # import asyncio
 import ujson
-from .request import create_request, StatusRequest
+from .request import create_request, StatusRequest, UpdateCollectionsRequest
 from sanic_cors import CORS, cross_origin
 import os
 import sys
@@ -161,8 +161,6 @@ async def process_request(request):
 async def process_request(request, datasource):
     epiviz_request = StatusRequest(request, datasource)
     result, error = await epiviz_request.get_status(request.app.epivizMeasurementsManager)
-    print(result)
-    print(error)
 
     result = "ok: {} bytes read".format(result) if result > 0 else "fail"
     return response.json({
@@ -172,3 +170,17 @@ async def process_request(request, datasource):
             "version": 5,
             "data": "check status of datasource " + datasource + ": " + result},
         status=200)
+
+@app.route("/updateCollections", methods=["POST"])
+async def process_request(request):
+    epiviz_request = UpdateCollectionsRequest(request)
+    result, error = await epiviz_request.update_collections(request.app.epivizMeasurementsManager)
+    status_code = 201 if len(error) == 0 else 501
+        
+    return response.json({
+            "requestId": -1,
+            "type": "response",
+            "error": error,
+            "version": 5,
+            "data": result},
+        status = status_code)
